@@ -4,7 +4,6 @@
 #' Exploratory and Descriptive analysis of event based data in R,
 #' developed by the Business Informatics Research Group of Hasselt University.
 #'
-#'
 #' @docType package
 #' @name edeaR
 #'
@@ -27,7 +26,9 @@
 #' @importFrom utils data
 
 
-globalVariables(c(".N","event_classifier", "activity_instance_classifier", "absolute_frequency", "Freq","q1", "q3","st_dev",
+
+globalVariables(c(".N","event_classifier", "activity_group", "aid","first_activity","first_resource","last_activity","last_resource",
+				  "activity_instance_classifier", "absolute_frequency", "Freq","q1", "q3","st_dev", "next_activity","nr_of_resources","same_activity",
 				  "relative_trace_frequency", "case_classifier", "timestamp_classifier", "last_event", "absolute", "cum_sum", "event_concept.name",				  "event_time.timestamp", "case_concept.name", "first_event", "duration_in_days", "conditions_valid", "starts_with",
 				  "duration", "start_timestamp","complete_timestamp", "complete","e","r","min_timestamp","max_rank","trace_id","act_freq",
 				  "s","dur","start", "relative_frequency","tot_dur","number_of_repetitions","denom", "instance",
